#Pupae cold tolerance
A<-read.table("tolerance pupes froid suzukii.txt", header=T)
A$survival=(A$emerging)/A$n
Fr<-na.omit(A)
attach(Fr)

temperature=as.factor(temperature)
yppfr<-cbind(Fr$emerging,Fr$n-Fr$emerging)
model<-glm(yppfr~temperature*duration, family=binomial(link=logit))
library(car)
Anova(model)

########## EFFECT PLOTS 
library(effects)
### All variables
plot(allEffects(model))
##### Variables and interactions
plot(effect("temperature ",model),ylab="Survival") 
plot(effect("duration ",model),ylab="Survival")         
plot(effect("temperature:duration",model),ylab="Survival")                          

Fr$predFr=predict(model, type="response")
predFr=as.numeric(unlist(Fr$predFr))

#################
# Plots:
x11()
par(mfrow=c(2,3), mar=c(4,4,1,1))
#-5C: 
d_5pup=subset(Fr,temperature=="-5")
attach(d_5pup)
plot(ylim=c(0,1), xlim=c(0,2.5),survival~duration, data=d_5pup, pch=15
     , col="black" ,lwd=1, ylab="Percentage survival" , xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(2.325,0.95,"-5C",col="Black", cex=2)
lines(predFr~duration, data=d_5pup, type="l",lty=1, pch=20,col="black",lwd=2)

#-2.5
d_2.5pup=subset(Fr,temperature=="-2.5")
attach(d_2.5pup)
plot(ylim=c(0,1), xlim=c(0,4),survival~duration, data=d_2.5pup, pch=15
     , col="black" ,lwd=1, ylab="", xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(3.65,0.95,"-2.5C",col="Black", cex=2)
lines(predFr~duration, data=d_2.5pup, type="l",lty=1, pch=20,col="black",lwd=2)

#0
d0pup=subset(Fr,temperature=="0")
attach(d0pup)
plot(ylim=c(0,1), xlim=c(0,72),survival~duration, data=d0pup, pch=15
     , col="black" ,lwd=1, ylab="", xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(67,0.95,"0C",col="Black", cex=2)
lines(predFr~duration, data=d0pup, type="l",lty=1, pch=20,col="black",lwd=2)

#2.5
d2.5pup=subset(Fr,temperature=="2.5")
attach(d2.5pup)
plot(ylim=c(0,1), xlim=c(0,100),survival~duration, data=d2.5pup, pch=15
     , col="black" ,lwd=1, ylab="Percentage survival" , xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(90,0.95,"2.5C",col="Black", cex=2)
lines(predFr~duration, data=d2.5pup, type="l",lty=1, pch=20,col="black",lwd=2)

#5
d5pup=subset(Fr,temperature=="5")
attach(d5pup)
plot(ylim=c(0,1), xlim=c(0,120),survival~duration, data=d5pup, pch=15
     , col="black" ,lwd=1, ylab=NA, xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(115,0.95,"5C",col="Black", cex=2)
lines(predFr~duration, data=d5pup, type="l",lty=1, pch=20,col="black",lwd=2)

#7.5
d7.5pup=subset(Fr,temperature=="7.5")
attach(d7.5pup)
plot(ylim=c(0,1), xlim=c(0,360),survival~duration, data=d7.5pup, pch=15
     , col="black" ,lwd=1, ylab=NA, xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(335,0.95,"7.5C",col="Black", cex=2)
lines(predFr~duration, data=d7.5pup, type="l",lty=1, pch=20,col="black",lwd=2)

#Lt50:
library(arm)
summary(model)

repet=sim(model,10000)
coef=coef(repet)
head(coef)
taux=0.5
#-5C
intercept=coef[,1]
slope=coef[,7]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#-2,5C
intercept=coef[,1]+coef[,2]
slope=coef[,7]+coef[,8]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#0C
intercept=coef[,1]+coef[,3]
slope=coef[,7]+coef[,9]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#2.5C
intercept=coef[,1]+coef[,4]
slope=coef[,7]+coef[,10]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#5C
intercept=coef[,1]+coef[,5]
slope=coef[,7]+coef[,11]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#7.5C
intercept=coef[,1]+coef[,6]
slope=coef[,7]+coef[,12]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
