# Pupae hot tolerance 
A<-read.table("tolerance pupes chaud suzukii.txt", header=T)
A$survival=(A$emerging)/A$n
Ch<-na.omit(A)
attach(Ch)

Temperature=as.factor(temperature)
yppCh<-cbind(Ch$emerging,Ch$n-Ch$emerging)
model<-glm(yppCh~Temperature*duration, family=binomial(link=logit))
library(car)
Anova(model)

########## EFFECT PLOTS 
library(effects)
### All variables
plot(allEffects(model))
##### Variables and interactions
plot(effect("Temperature ",model),ylab="Survival") 
plot(effect("duration ",model),ylab="Survival")         
plot(effect("Temperature:duration",model),ylab="Survival")                          

Ch$predCh=predict(model, type="response")
predCh=as.numeric(unlist(Ch$predCh))

#################
# Plots:
x11()
par(mfrow=c(3,3), mar=c(4,4,1,1))
#30C: 
d30pup=subset(Ch,Temperature=="30")
attach(d30pup)
plot(ylim=c(0,1), xlim=c(0,360),survival~duration, data=d30pup, pch=15
     , col="black" ,lwd=1, ylab="Percentage survival", xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(345,0.95,"30C",col="Black", cex=2)
lines(predCh~duration, data=d30pup, type="l",lty=1, pch=20,col="black",lwd=2)

#31
d31pup=subset(Ch,Temperature=="31")
attach(d31pup)
plot(ylim=c(0,1), xlim=c(0,120),survival~duration, data=d31pup, pch=15
     , col="black" ,lwd=1, ylab="", xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(112,0.95,"31C",col="Black", cex=2)
lines(predCh~duration, data=d31pup, type="l",lty=1, pch=20,col="black",lwd=2)

#32
d32pup=subset(Ch,Temperature=="32")
attach(d32pup)
plot(ylim=c(0,1), xlim=c(0,100),survival~duration, data=d32pup, pch=15
     , col="black" ,lwd=1, ylab=NA, xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(97,0.95,"32C",col="Black", cex=2)
lines(predCh~duration, data=d32pup, type="l",lty=1, pch=20,col="black",lwd=2)

#33
d33pup=subset(Ch,Temperature=="33")
attach(d33pup)
plot(ylim=c(0,1), xlim=c(0,50),survival~duration, data=d33pup, pch=15
     , col="black" ,lwd=1, ylab="Percentage survival", xlab=NA, mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(45,0.95,"33C",col="Black", cex=2)
lines(predCh~duration, data=d33pup, type="l",lty=1, pch=20,col="black",lwd=2)

#34
d34pup=subset(Ch,Temperature=="34")
attach(d34pup)
plot(ylim=c(0,1), xlim=c(0,50),survival~duration, data=d34pup, pch=15
     , col="black" ,lwd=1, ylab=NA, xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(45,0.95,"34C",col="Black", cex=2)
lines(predCh~duration, data=d34pup, type="l",lty=1, pch=20,col="black",lwd=2)

#35
d35pup=subset(Ch,Temperature=="35")
attach(d35pup)
plot(ylim=c(0,1), xlim=c(0,50),survival~duration, data=d35pup, pch=15
     , col="black" ,lwd=1, ylab=NA, xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(45,0.95,"35C",col="Black", cex=2)
lines(predCh~duration, data=d35pup, type="l",lty=1, pch=20,col="black",lwd=2)

#37
d37pup=subset(Ch,Temperature=="37")
attach(d37pup)
plot(ylim=c(0,1), xlim=c(0,10),survival~duration, data=d37pup, pch=15
     , col="black" ,lwd=1, ylab="Percentage survival", xlab="Exposure duration (h)", mgp=c(2.5, 1, 0), cex.axis=1.5, cex.lab=1.5)  
text(8,0.95,"37C",col="Black", cex=2)
lines(predCh~duration, data=d37pup, type="l",lty=1, pch=20,col="black",lwd=2)


#Lt50:
library(arm)
summary(model)

repet=sim(model,10000)
coef=coef(repet)
head(coef)
taux=0.5 

#30C
intercept=coef[,1]
slope=coef[,8]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#31C
intercept=coef[,1]+coef[,2]
slope=coef[,8]+coef[,9]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#32C
intercept=coef[,1]+coef[,3]
slope=coef[,8]+coef[,10]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#33C
intercept=coef[,1]+coef[,4]
slope=coef[,8]+coef[,11]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#34C
intercept=coef[,1]+coef[,5]
slope=coef[,8]+coef[,12]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#35C
intercept=coef[,1]+coef[,6]
slope=coef[,8]+coef[,13]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
#37C
intercept=coef[,1]+coef[,7]
slope=coef[,8]+coef[,14]
LT=(logit(taux)-intercept)/slope

mean(LT);sd(LT);quantile(LT,p=c(0.025,0.975))
